@@ -7,16 +7,14 @@ import time
 class SSHConn:
     """ 维护一个基于ssh协议的linux连接 """
 
-    def connect(self, host, port, user, pwd):
+    def __init__(self, host, port, user, pwd):
         """ 给入连接信息初始化该连接 """
-        self.close()
         self.transport = paramiko.Transport(host, port)
         self.transport.connect(username=user, password=pwd)
         self.client = paramiko.SSHClient()
         self.client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         self.client.connect(host, port, user, pwd, timeout=3)
         time.sleep(1)
-        return self
 
     def exec_command(self, cmd):
         """ 执行单一命令，返回结果 """
